package eu.dnetlib.scholix.api;

import eu.dnetlib.common.app.AbstractDnetApp;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.context.annotation.Bean;
import org.springframework.scheduling.annotation.EnableScheduling;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

@SpringBootApplication
@EnableSwagger2
@EnableCaching
@EnableScheduling
//@EntityScan("eu.dnetlib.scholix.api.controller")
public class MainApplication extends AbstractDnetApp {

	@Value("${dhp.swagger.api.host}")
	private String swaggetHost;

	@Value("${dhp.swagger.api.basePath}")
	private String swaggerPath;

	final String descriptionAPI = " <p style=\"text-align:center;\"><img src=\"/logo.png\" alt=\"ScholeXplorer\"> </p>" +
			"The Scholix Swagger API allows clients to run REST queries over the Scholexplorer index in order to fetch links matching given criteria. In the current version, clients can search for:" +
			"<ul><li>Links whose source object has a given PID or PID type</li>" +
			"<li>Links whose source object has been published by a given data source (\"data source as publisher\")</li>" +
			"<li>Links that were collected from a given data source (\"data source as provider\").</li></ul>";

	public static void main(final String[] args) {
		SpringApplication.run(MainApplication.class, args);
	}

	@Override
	protected void configSwagger(final Docket docket) {
		docket
			.host(swaggetHost)
			.pathMapping(swaggerPath)
			.groupName("Scholexplorer V1")
			.select()
			.apis(RequestHandlerSelectors.any())
			.paths(p -> p.startsWith("/v1"))
			.build()
			.apiInfo(new ApiInfoBuilder()
				.title("Scholexplorer API V1.0")
				.description(descriptionAPI)
				.version("1.0")
				.contact(ApiInfo.DEFAULT_CONTACT)
				.license("Apache 2.0")
				.licenseUrl("http://www.apache.org/licenses/LICENSE-2.0")
				.build());
	}



	@Bean (name = "SpringDOcketv2")
	public Docket v2Docket() {


		final Docket docket = new Docket(DocumentationType.SWAGGER_2);

		docket
				.host(swaggetHost)
				.pathMapping(swaggerPath)
				.groupName("Scholexplorer V2")
				.select()
				.apis(RequestHandlerSelectors.any())
				.paths(p -> p.startsWith("/v2"))
				.build()
				.apiInfo(new ApiInfoBuilder()
						.title("Scholexplorer API V2.0")
						.description(descriptionAPI)
						.version("2.0")
						.contact(ApiInfo.DEFAULT_CONTACT)
						.license("Apache 2.0")
						.licenseUrl("http://www.apache.org/licenses/LICENSE-2.0")
						.build());

		return docket;
	}

}
