package eu.dnetlib.scholix.api.model.v2;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;

import javax.validation.constraints.NotNull;

/**
 * The type Relationship type.
 */
public class RelationshipType {

    @NotNull
    @JsonProperty("Name")
    private String name;

    @JsonProperty("SubType")
    private String subType;

    @JsonProperty("SubTypeSchema")
    private String subTypeSchema;


    /**
     * Gets The relationship type chosen from a Scholix controlled vocabulary
     *
     * @return the name
     */
    @Schema(description = "The relationship type chosen from a Scholix controlled vocabulary")
    public String getName() {
        return name;
    }

    /**
     * Sets The relationship type chosen from a Scholix controlled vocabulary
     *
     * @param name the name
     * @return the RelationshipType instance
     */
    public RelationshipType setName(String name) {
        this.name = name;
        return this;
    }

    /**
     * Gets The sub-type of RelationshipType.Name
     *
     * @return the sub type
     */
    @Schema(description = "The sub-type of RelationshipType.Name")
    public String getSubType() {
        return subType;
    }

    /**
     * Sets The sub-type of RelationshipType.Name
     *
     * @param subType the sub type
     * @return the RelationshipType instance
     */
    public RelationshipType setSubType(String subType) {
        this.subType = subType;
        return this;
    }

    /**
     * Gets The name of the schema or controlled list from which RelationshipSub-type is sourced.
     *
     * @return the sub type schema
     */
    @Schema(description = "The name of the schema or controlled list from which RelationshipSub-type is sourced")
    public String getSubTypeSchema() {
        return subTypeSchema;
    }

    /**
     * Sets The name of the schema or controlled list from which RelationshipSub-type is sourced.
     *
     * @param subTypeSchema the sub type schema
     * @return the RelationshipType instance
     */
    public RelationshipType setSubTypeSchema(String subTypeSchema) {
        this.subTypeSchema = subTypeSchema;
        return this;
    }
}
