package eu.dnetlib.scholix.api.model.v2;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;

import javax.validation.constraints.NotBlank;
import java.util.ArrayList;
import java.util.List;

/**
 * The type Scholix creator type.
 */
public class ScholixCreatorType {

    @NotBlank
    @JsonProperty("name")
    private String name = null;


    @NotBlank
    @JsonProperty("identifier")
    private List<ScholixIdentifierType> identifier = new ArrayList<>();

    /**
     * Gets A List of unique string that identifies the creator
     *
     * @return the identifier
     */
    @Schema(description = "A List of unique string that identifies the creator")
    public List<ScholixIdentifierType> getIdentifier() {
        return identifier;
    }

    /**
     * Sets A List of unique string that identifies the creator
     *
     * @param identifier the identifier
     * @return the identifier
     */
    public ScholixCreatorType setIdentifier(List<ScholixIdentifierType> identifier) {
        this.identifier = identifier;
        return this;
    }


    /**
     * Gets The name of the Object Creator
     *
     * @return the name
     */
    @Schema(description = "The name of the Object Creator")
    public String getName() {
        return name;
    }

    /**
     * Sets The name of the Object Creator
     *
     * @param name the name
     * @return the name
     */
    public ScholixCreatorType setName(String name) {
        this.name = name;
        return this;
    }
}
